@@ -21,6 +21,7 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <games-clock.h>
 
 #include "othello.h"
 #include "gnothello.h"
@@ -210,15 +211,19 @@ gint move_board(gint8 board[8][8], guint x, guint y, guint me, gint real)
 		if(whose_turn == WHITE_TURN) {
 			whose_turn = BLACK_TURN;
 			gui_message(_("Dark's move"));
+		
 			if(!white_computer_level) {
-				gtk_clock_stop(GTK_CLOCK(time_display));
+				games_clock_stop(GAMES_CLOCK(time_display));
 			}
+		
 		} else {
 			whose_turn = WHITE_TURN;
 			gui_message(_("Light's move"));
+		
 			if(!black_computer_level) {
-				gtk_clock_stop(GTK_CLOCK(time_display));
+				games_clock_stop(GAMES_CLOCK(time_display));
 			}
+		
 		}
 
 		pixmaps[x][y] = me;
@@ -426,10 +431,10 @@ gint move_board(gint8 board[8][8], guint x, guint y, guint me, gint real)
 		gui_status();
 
 		if(not_me == BLACK_TURN && !black_computer_level && timer_valid) {
-			gtk_clock_start(GTK_CLOCK(time_display));
+			games_clock_start(GAMES_CLOCK(time_display));
 		}
 		if(not_me == WHITE_TURN && !white_computer_level && timer_valid) {
-			gtk_clock_start(GTK_CLOCK(time_display));
+			games_clock_start(GAMES_CLOCK(time_display));
 		}
 
 		tiles_to_flip = 1;
@@ -603,7 +608,9 @@ gint check_valid_moves()
 	}
 
 	if(!white_moves && !black_moves) {
-		gtk_clock_stop(GTK_CLOCK(time_display));
+
+		games_clock_stop(GAMES_CLOCK(time_display));
+
 		white_moves = count_pieces(WHITE_TURN);
 		black_moves = count_pieces(BLACK_TURN);
 		if(white_moves > black_moves)
@@ -625,9 +632,9 @@ gint check_valid_moves()
 		whose_turn = BLACK_TURN;
 		if(white_computer_level ^ black_computer_level) {
 			if(!black_computer_level && timer_valid)
-				gtk_clock_start(GTK_CLOCK(time_display));
+				games_clock_start(GAMES_CLOCK(time_display));
 			else
-				gtk_clock_stop(GTK_CLOCK(time_display));
+				games_clock_stop(GAMES_CLOCK(time_display));		
 		}
 		return(TRUE);
 	}
@@ -637,9 +644,9 @@ gint check_valid_moves()
 		whose_turn = WHITE_TURN;
 		if(white_computer_level ^ black_computer_level) {
 			if(!white_computer_level && timer_valid)
-				gtk_clock_start(GTK_CLOCK(time_display));
+				games_clock_start(GAMES_CLOCK(time_display));
 			else
-				gtk_clock_stop(GTK_CLOCK(time_display));
+				games_clock_stop(GAMES_CLOCK(time_display));
 		}
 		return(TRUE);
 	}
