@@ -1075,7 +1075,7 @@ you_won (void)
         seconds = GAMES_CLOCK (chrono)->stopped;
 
         score = (seconds / 60) * 1.0 + (seconds % 60) / 100.0;
-        if (!(pos = gnome_score_log (score, score_current_mapset, FALSE))) {
+        if (pos = gnome_score_log (score, score_current_mapset, FALSE)) {
                 gnome_scores_display (_(APPNAME_LONG), APPNAME, score_current_mapset, pos);
                 message = g_strdup_printf
 			(_("Fantastic!  %.2f!\n"
@@ -1467,7 +1467,7 @@ confirm_action (GtkWidget *widget, gpointer data)
 			break;
 		case QUIT_GAME :
 			/* GNOME IS AN ACRONYM, DAMNIT! */
-			confirm_text = _("Really exit GNOME Mahjongg?");
+			confirm_text = _("Are you sure you want to quit GNOME Mahjongg?");
 			break;
 		case NEW_GAME:
 		case NEW_GAME_WITH_SEED:
@@ -1477,12 +1477,31 @@ confirm_action (GtkWidget *widget, gpointer data)
 			confirm_text = _("Serious internal error");
 			break;
 		}
-			
-		dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+
+		/* Special case the quit because the buttons are different */
+
+		if ((game_state)data == QUIT_GAME)
+		{
+			dialog = gtk_message_dialog_new (GTK_WINDOW (window),
 						 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_QUESTION,
-						 GTK_BUTTONS_YES_NO,
+						 GTK_BUTTONS_NONE,
 						 confirm_text);
+			gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+						GTK_STOCK_CANCEL,
+						GTK_RESPONSE_NO,
+						GTK_STOCK_QUIT,
+						GTK_RESPONSE_YES,
+						NULL);
+		}
+		else {
+                        dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                                                 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                 GTK_MESSAGE_QUESTION,
+                                                 GTK_BUTTONS_YES_NO,
+                                                 confirm_text);
+		}
+
 		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
 
 		response = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -1988,6 +2007,41 @@ shuffle_tiles_callback (GtkWidget *widget, gpointer data)
         }
 }
 
+static void 
+gconf_sanity_check(void)
+{
+  gchar *tileset;
+  GError *error = NULL;
+  
+  tileset = gconf_client_get_string (conf_client,
+                                     "/apps/mahjongg/tileset", &error);
+  if (error) {
+    GtkWidget *dialog;
+    dialog = gtk_message_dialog_new (NULL,
+                                     0,
+                                     GTK_MESSAGE_ERROR,
+                                     GTK_BUTTONS_CLOSE,
+                                     _("There was an error accessing GConf: %s"),
+                                     error->message);
+    gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+    gtk_dialog_run(GTK_DIALOG(dialog));
+    exit(1);
+  } else if (!tileset) {
+    GtkWidget *dialog;
+    dialog = gtk_message_dialog_new (NULL,
+                                     0,
+                                     GTK_MESSAGE_ERROR,
+                                     GTK_BUTTONS_CLOSE,
+                                     _("The default configuration values could not be retrieved correctly. Please check your GConf configuration, specifically that the schemas are installed correctly"));
+    gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+    gtk_dialog_run(GTK_DIALOG(dialog));
+    exit(1);
+  } else {
+    g_message(tileset);
+    g_free (tileset);
+  }
+}
+
 int
 main (int argc, char *argv [])
 {
@@ -2012,6 +2066,7 @@ main (int argc, char *argv [])
         gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-mahjongg.png");
 	new_seed ();
 	conf_client = gconf_client_get_default ();
+	gconf_sanity_check();
 
 	window = gnome_app_new (APPNAME, _(APPNAME_LONG));
 	gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
